@@ -2,7 +2,11 @@ import os
 import errno
 import random
 import time
-import procname
+try:
+    from procname import setprocname
+except ImportError:
+    def setprocname(*args, **kwargs):  # noqa
+        pass
 import socket
 import signal
 import traceback
@@ -16,7 +20,7 @@ from .queue import Queue, get_failed_queue
 from .connections import get_current_connection
 from .utils import make_colorizer
 from .exceptions import NoQueueError, UnpickleError
-from .timeouts import death_pentalty_after
+from .timeouts import death_penalty_after
 
 green = make_colorizer('darkgreen')
 yellow = make_colorizer('darkyellow')
@@ -50,15 +54,17 @@ class Worker(object):
     redis_workers_keys = 'rq:workers'
 
     @classmethod
-    def all(cls):
+    def all(cls, connection=None):
         """Returns an iterable of all Workers.
         """
-        conn = get_current_connection()
-        reported_working = conn.smembers(cls.redis_workers_keys)
-        return compact(map(cls.find_by_key, reported_working))
+        if connection is None:
+            connection = get_current_connection()
+        reported_working = connection.smembers(cls.redis_workers_keys)
+        workers = [cls.find_by_key(key, connection) for key in reported_working]
+        return compact(workers)
 
     @classmethod
-    def find_by_key(cls, worker_key):
+    def find_by_key(cls, worker_key, connection=None):
         """Returns a Worker instance, based on the naming conventions for
         naming the internal Redis keys.  Can be used to reverse-lookup Workers
         by their Redis keys.
@@ -68,14 +74,15 @@ class Worker(object):
         if not worker_key.startswith(prefix):
             raise ValueError('Not a valid RQ worker key: %s' % (worker_key,))
 
-        conn = get_current_connection()
-        if not conn.exists(worker_key):
+        if connection is None:
+            connection = get_current_connection()
+        if not connection.exists(worker_key):
             return None
 
         name = worker_key[len(prefix):]
         worker = cls([], name)
-        queues = conn.hget(worker.key, 'queues')
-        worker._state = conn.hget(worker.key, 'state') or '?'
+        queues = connection.hget(worker.key, 'queues')
+        worker._state = connection.hget(worker.key, 'state') or '?'
         if queues:
             worker.queues = map(Queue, queues.split(','))
         return worker
@@ -157,7 +164,7 @@ class Worker(object):
 
         This can be used to make `ps -ef` output more readable.
         """
-        procname.setprocname('rq: %s' % (message,))
+        setprocname('rq: %s' % (message,))
 
 
     def register_birth(self):  # noqa
@@ -350,7 +357,7 @@ class Worker(object):
             job.origin, time.time()))
 
         try:
-            with death_pentalty_after(job.timeout or 180):
+            with death_penalty_after(job.timeout or 180):
                 rv = job.perform()
         except Exception as e:
             fq = self.failed_queue
